/******************************************************************************/
/* SISTEMAS INTEGRADOS TECNISA                                                */
/*                                                                            */
/* COMPRAS E SUPRIMENTOS                                                      */
/*                                                                            */
/******************************************************************************/
/*                                                                            */
/* NOME:                                                                      */
/*   GERA_NF_AF_PARCIAL                                                       */
/* DESCRIO:                                                                 */
/* ROTINA PARA GRAVAR CORPO DE NOTA FISCAL QUANDO A BAIXA FOR PARCIAL.        */
/*                                                                            */
/* CRIAO:                                                                   */
/*  20/10/2000 - ADRIANO DE ARAJO                                            */
/*                                                                            */
/******************************************************************************/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
          WHERE
            O.NAME = 'GERA_NF_AF_PARCIAL' AND
            TYPE = 'P'                    AND
            U.UID = O.UID                 AND
            U.NAME = USER)

DROP PROCEDURE GERA_NF_AF_PARCIAL;
GO

CREATE PROCEDURE GERA_NF_AF_PARCIAL
   @P_CDFILIAL   VARCHAR(04),
   @P_NRLANCTONF VARCHAR(10)
AS
   DECLARE @V_CODIGO VARCHAR(20);
   DECLARE @V_CONC   VARCHAR;
   DECLARE @V_TOTNF  NUMERIC;
BEGIN
   SET @V_CODIGO = NULL;
   SET @V_CONC   = 'LANCNF/FILIAL'+@P_CDFILIAL;

   SELECT
      @V_TOTNF = MAX(AUTOFORNE.VRTOTALAF) 
   FROM
      ITEMAUTF,
      AUTOFORNE
   WHERE
      ITEMAUTF.CDFILLANC  = @P_CDFILIAL   AND
      ITEMAUTF.NRLANCTONF = @P_NRLANCTONF AND
      ISNULL(ITEMAUTF.QTEFETENTRAF,0) < ITEMAUTF.QTPROGENTAF AND
      AUTOFORNE.CDFILDEST  = ITEMAUTF.CDFILDEST AND
      AUTOFORNE.CDFILLANC  = ITEMAUTF.CDFILLANC AND
      AUTOFORNE.NRAUTOFORN = ITEMAUTF.NRAUTOFORN;

   IF @V_TOTNF IS NOT NULL BEGIN

      EXEC NOVO_CODIGO @V_CONC, @P_SEQUENCIAL = @V_CODIGO OUTPUT;

      INSERT INTO NOTAFISCAL
      (CDFILIAL, NRLANCTONF, CDEMPRESA,
       CDINSCESTA, CDINSCMUNI, CDFORNECED, IDBLOQUEADO, VRPRODUTOS,
       VRNOTAFISC, IDENTRSAIDOP, IDSTATUS, CDTIPOOPER, DTENTRSAID,
       IDSISTEMA, CDFILIRECE)
      SELECT
         CDFILIAL, SUBSTRING(@V_CODIGO, 11, 10), CDEMPRESA,
         CDINSCESTA, CDINSCMUNI, CDFORNECED, 'N', VRPRODUTOS,
         (@V_TOTNF - VRNOTAFISC), 'E', 'V', CDTIPOOPER, DTENTRSAID,
         'CMP', CDFILIRECE
      FROM
         NOTAFISCAL
      WHERE
         CDFILIAL   = @P_CDFILIAL AND
         NRLANCTONF = @P_NRLANCTONF;

      UPDATE ITEMAUTF
      SET NRLANCTONF = SUBSTRING(@V_CODIGO, 11, 10)
      WHERE
         ITEMAUTF.CDFILLANC  = @P_CDFILIAL AND
         ITEMAUTF.NRLANCTONF = @P_NRLANCTONF AND
         ISNULL(ITEMAUTF.QTEFETENTRAF,0) < ITEMAUTF.QTPROGENTAF;
   END;
END;
GO
